@@ -4,23 +4,29 @@ from __future__ import absolute_import
 
 # import apis into api package
 from lusid.api.aggregation_api import AggregationApi
-from lusid.api.analytics_stores_api import AnalyticsStoresApi
+from lusid.api.allocations_api import AllocationsApi
 from lusid.api.application_metadata_api import ApplicationMetadataApi
+from lusid.api.calendars_api import CalendarsApi
 from lusid.api.configuration_recipe_api import ConfigurationRecipeApi
+from lusid.api.conventions_api import ConventionsApi
 from lusid.api.corporate_action_sources_api import CorporateActionSourcesApi
 from lusid.api.cut_label_definitions_api import CutLabelDefinitionsApi
 from lusid.api.data_types_api import DataTypesApi
 from lusid.api.derived_transaction_portfolios_api import DerivedTransactionPortfoliosApi
 from lusid.api.entities_api import EntitiesApi
 from lusid.api.instruments_api import InstrumentsApi
+from lusid.api.legal_entities_api import LegalEntitiesApi
 from lusid.api.login_api import LoginApi
+from lusid.api.orders_api import OrdersApi
+from lusid.api.persons_api import PersonsApi
 from lusid.api.portfolio_groups_api import PortfolioGroupsApi
 from lusid.api.portfolios_api import PortfoliosApi
 from lusid.api.property_definitions_api import PropertyDefinitionsApi
 from lusid.api.quotes_api import QuotesApi
 from lusid.api.reconciliations_api import ReconciliationsApi
 from lusid.api.reference_portfolio_api import ReferencePortfolioApi
-from lusid.api.results_api import ResultsApi
+from lusid.api.relation_definitions_api import RelationDefinitionsApi
+from lusid.api.relations_api import RelationsApi
 from lusid.api.schemas_api import SchemasApi
 from lusid.api.scopes_api import ScopesApi
 from lusid.api.search_api import SearchApi
